## Important design decisions

The following information should hopefully help you to determine if this TAXII implementation is right for you.

### STIX / TAXII versions

* this server is only designed to serve/accept STIX 2.1 objects
* this server is built to the TAXII 2.1 specification
	* All TAXII 2.1 endpoints are implemented as per the specification here (dated 10 June 2021): https://docs.oasis-open.org/cti/taxii/v2.1/taxii-v2.1.html

### Databases

This code is only designed to work with ArangoDB. That includes all versions of ArangoDB, including the free community edition.

### Users / Authentication / Permissions

Authentication is managed by ArangoDB.

Under the `_system` database, admin users can add or remove other users from the system.

Each user has a username and password.

These values are used to authenticate against the API, using basic auth in the header of each request;

```
Authorization: Basic <credentials>
```

Users can also be assigned permissions on a database and Collection level.

A user can be assigned read/write or read permissions to a Collection.

* Users with no permissions cannot see the database or collection.
* Users with read can view objects in the collection
* Users with read/write can view objects in the collection as well as add and delete objects in the collection.

### ArangoDB -> TAXII mapping

ArangoDB has the following structure

```txt
├── database
│   ├── document collection
│   ├── document collection N
│   ├── edge collection
│   └── edge collection N
├── database N
│   ├── document collection
│   ├── document collection N
│   ├── edge collection
│   └── edge collection N
├── ...
```

An ArangoDB database has the following attributes;

* `name` (required)
* `identifier` (autogenerated)

An ArangoDB collection has the following attributes;

* `name` (required)
* `type` (required): either document or edge
* `identifier` (autogenerated)

TAXII has the following structure

```txt

├── api-root
│	├── collection
│   │	└── stix objects
│   └── collection
│   	└── stix objects
├── api-root
│	├── collection
│   │	└── stix objects
│   └── collection
│   	└── stix objects
├── ...
```

A TAXII root has the following attributes;

* `title` (required)
* `description` (optional)
* `versions` (required)
* `max_content_length` (required)

A TAXII collection has the following attributes:

* `id` (required)
* `title` (required)
* `description` (optional)
* `alias` (optional)
* `can_read` (required)
* `can_write` (required)
* `media_types` (optional)

In Arango TAXII Server; ArangoDB Databases map to TAXII API Roots as follow...

TAXII attribute -> ArangoDB attribute

* `taxii.api-root.title` -> `arango.database.name`
* `taxii.api-root.versions` -> not inherited from arango (always `application/taxii+json;version=2.1` as this is what Arango TAXII Server supports)
* `taxii.api-root.max_content_length` -> not inherited from arango (set in the conf file but determined at the webserver level based on maximum size it can support for responses, thus will be the same value for all API Roots)

In Arango TAXII server; ArangoDB Collections map to TAXII Collections as follow...

TAXII attribute -> ArangoDB attribute

* `taxii.collection.id` -> `arango.collection.identifier`
* `taxii.collection.title` -> `arango.collection.name (without type -- see stix2arango coupling)`
* `taxii.collection.alias` -> `arango.collection.name (without type -- see stix2arango coupling)`
* `taxii.collection.can_read` -> not inherited from arango (this is dynamic, is boolean depending if authorised user can read collection. In reality should always be `TRUE` as users should not be shown any collections they cannot read)
* `taxii.collection.can_write` -> not inherited from arango (this is dynamic, is boolean depending if authorised user can write to collection)
* `taxii.collection.media_types` -> not inherited from arango (always `application/stix+json;version=2.1` because we only ever store STIX 2.1 objects)